@@ -1,11 +1,9 @@
-__version__ = '0.4.4'
+__version__ = '0.4.5'
 
 
 from ._upath import Upath, FileInfo, LockAcquisitionTimeoutError
 from ._local import LocalUpath
 from ._blob import BlobUpath
-from ._azure import AzureBlobUpath
-from ._gcp import GcpBlobUpath
 
 
 __all__ = [
@@ -14,6 +12,4 @@ __all__ = [
     'LockAcquisitionTimeoutError',
     'LocalUpath',
     'BlobUpath',
-    'AzureBlobUpath',
-    'GcpBlobUpath',
 ]
