@@ -8,6 +8,7 @@ import abc
 import asyncio
 import concurrent.futures
 import contextlib
+import datetime
 import gc
 import json
 import logging
@@ -31,9 +32,11 @@ class LockAcquisitionTimeoutError(TimeoutError):
 
 @dataclass
 class FileInfo:
-    size: int      # in bytes
     ctime: float   # creation POSIX timetamp
     mtime: float   # last modification POSIX timestamp
+    timed_created: datetime.datetime
+    timed_modified: datetime.datetime
+    size: int      # in bytes
     details: Any   # platform-dependent
 
 
@@ -190,6 +193,8 @@ class Upath(abc.ABC):  # pylint: disable=too-many-public-methods
                     # We're assuming that this suggests
                     # the target file was copied from the source
                     # previously.
+                    logger.info(
+                        f"target {target!r} appears to be up-to-date; skipped")
                     return 0
             logger.info("copying '%s' to '%s'", self, target)
             target.write_bytes(self.read_bytes(), overwrite=True)
